@@ -1,3 +1,5 @@
+#ifndef DIST_H
+#define DIST_H
 
 double dist(double x1, double y1, double x2, double y2);
 
@@ -5,3 +7,4 @@ double dist2(double x1, double y1, double x2, double y2);
 
 double norm(double *x, int dim);
 
+#endif
